@@ -95,7 +95,7 @@ setMethodS3("plotFitLayers", "CopyNumberChromosomalModel", function(this, FUN, p
     
       verbose && enter(verbose, sprintf("Plotting %s for chromosome %02d [%.2fMB]", arrayName, chromosome, widthMb));
   
-      for (zz in seq(along=zooms)) {
+      for (zz in seq_along(zooms)) {
         zoom <- zooms[zz];
   
         # Create the pathname to the file
@@ -156,7 +156,7 @@ setMethodS3("plotFitLayers", "CopyNumberChromosomalModel", function(this, FUN, p
   fit(this, ..., .retResults=FALSE, verbose=verbose);
 
   invisible();
-}) # plotFitLayers()
+}, protected=TRUE) # plotFitLayers()
 
 
 
